@@ -115,13 +115,15 @@ Note that you have to explicitly set
 and not simply return an error message as a result.
 """
 
+import contextlib
 from cgi import escape as _escape
 from sys import exc_info as _exc_info
 from traceback import format_exception as _format_exception
+from xml.sax import saxutils
 
 import six
 
-from cherrypy._cpcompat import basestring, iteritems, ntob
+from cherrypy._cpcompat import text_or_bytes, iteritems, ntob
 from cherrypy._cpcompat import tonative, urljoin as _urljoin
 from cherrypy.lib import httputil as _httputil
 
@@ -209,7 +211,7 @@ class HTTPRedirect(CherryPyException):
         import cherrypy
         request = cherrypy.serving.request
 
-        if isinstance(urls, basestring):
+        if isinstance(urls, text_or_bytes):
             urls = [urls]
 
         abs_urls = []
@@ -269,7 +271,6 @@ class HTTPRedirect(CherryPyException):
                 307: "This resource has moved temporarily to ",
             }[status]
             msg += '<a href=%s>%s</a>.'
-            from xml.sax import saxutils
             msgs = [msg % (saxutils.quoteattr(u), u) for u in self.urls]
             response.body = ntob("<br />\n".join(msgs), 'utf-8')
             # Previous code may have set C-L, so we have to reset it
@@ -413,6 +414,15 @@ class HTTPError(CherryPyException):
         """Use this exception as a request.handler (raise self)."""
         raise self
 
+    @classmethod
+    @contextlib.contextmanager
+    def handle(cls, exception, status=500, message=''):
+        """Translate exception into an HTTPError."""
+        try:
+            yield
+        except exception as exc:
+            raise cls(status, message or str(exc))
+
 
 class NotFound(HTTPError):
 
